package be.vmm.lucht.data.dao;

import java.util.List;

import be.vmm.lucht.data.model.MeetPrincipe;

/**
 * Interface voor het specifiëren van meetPrincipe-gerelateerd DB operaties.
 * 
 * @author vandrth
 */
public interface IMeetPrincipeDao {

	/**
	 * Ophalen van alle actieve meetprincipes.
	 * 
	 * @return List<MeetPrincipe> De gevonden meetprincipes.
	 */
	List<MeetPrincipe> findAllActieve();

	/**
	 * Zoekt het meetprincipe met de gegeven naam. Aangezien de naam uniek is
	 * kan er maar 1 meetprincipe zijn met die naam.
	 * 
	 * @param naam
	 *            De naam van het te zoeken meetprincipe.
	 * @return {@link MeetPrincipe} Het meetprincipe met de gegeven naam of
	 *         <code>null</code> indien niet gevonden.
	 */
	MeetPrincipe findByNaam(String naam);

	/**
	 * Zoekt het meetprincipe met de gegeven code. Aangezien de code uniek is
	 * kan er maar 1 meetprincipe zijn met die code.
	 * 
	 * @param code
	 *            De code van het te zoeken meetprincipe.
	 * @return {@link MeetPrincipe} Het meetprincipe met de gegeven code of
	 *         <code>null</code> indien niet gevonden.
	 */
	MeetPrincipe findByCode(String code);

	List<MeetPrincipe> findAll();

}
